/**
 * 判断运行平台是否为ios设备
 * @param platform  设备平台，即'android'或'ios'
 * @returns {boolean}
 */
function isIos(platform) {
    return /ios/i.test(platform);
}

// var poiData = window.sessionStorage.getItem('poi');
// alert(poiData)
/**
 * 调用客户端的拨打电话功能
 * @param platform  设备平台，即'android'或'ios'
 * @param tel   如果是多组电话，以半角';'相连，如A;B;C
 */
function nativeDial(platform, tel) {
    mqq.invoke('common', 'callUp', {phone: decodeURI(tel)});
}
/**
 * 获取设备的基本信息
 * @param callBack({"platform":"android","imei":"99000672608672","appVersion":"6.7.0"})
 */
function nativeDeviceInfo(callBack) {
    //alert("客户端调取设备信息")
    mqq.invoke('common','getDeviceInfo',{}, function (data) {
        if (data) {
            callBack(data);
        } else {
            callBack(undefined);
        }
    })
}
/**
 * 获取是否是测试环境
 * @param callBack({"isTest":0})
 */
function nativeIsTest(callBack) {
    mqq.invoke('common','isTest',{
    }, function (data) {
        // alert("data="+JSON.stringify(data))
        if (data.isTest.toString()) {
            // alert("isTest1="+data.isTest)
            callBack(data.isTest);
        } else {
            callBack(undefined);
        }
    })
}
/**
 * 获取是否零流量
 * @param callBack({"isOffline":0})
 */
function nativeIsOffline(callBack) {
    mqq.invoke('common','isOffline',{
    }, function (data) {
        if (data.isOffline.toString()) {
            callBack(data.isOffline);
        } else {
            callBack(undefined);
        }
    })
}
/**
 * 获取当前城市名称
 * @param callBack({"currentCity":cityName})
 */
function nativeCurrentCity(callBack) {
    mqq.invoke('common','currentCity',{
    }, function (data) {
        if (data.currentCity) {
            callBack(data.currentCity);
        } else {
            callBack(undefined);
        }
    })
}
/**
 * 获取当前坐标
 * @param callBack(｛"status":0, "lon":latE6,"lat":latE6,"alt":0,"acc":10,"dir"0,"spd":0,"time":14958954135756｝)
 */
function nativeGetPosition(callBack) {
    mqq.invoke('common', 'getPosition', {},
        function (data) {
            if (data && data.status == 0) {
                callBack(data.lat, data.lon);
            } else {
                callBack(undefined, undefined);
            }
        });
}
/**
 * 从客户端获取指定坐标所属的城市名称
 * @param latitude    坐标的纬度（浮点格式）
 * @param longitude    坐标的经度（浮点格式）
 * @param callBack(｛"city": 北京市｝)
 */
function nativeGetCity(latitude,longitude,callBack) {
    mqq.invoke('common','getCity', {'latitude': latitude, 'longitude': longitude}, function (data) {
        if (data.city) {
            callBack(data.city);
        } else {
            callBack(undefined);
        }
    })
}
/**
 * 调用客户端展示tips
 * @param content  展示的内容
 */
function nativeShowTips(content) {
    mqq.invoke('common', 'showTips', {'content': content});
}
/**
 * 获取当前详情页的POI数据
 * @param callBack(POI完整信息)
 */
function nativeGetPoi(callBack) {
    mqq.invoke('poi', 'getPoi', {key: 'poi'}, function (data) {
        if (data) {
            callBack(data);
        } else {
            callBack(undefined);
        }
    })
}
/**
 * 获取出行方式
 * @param callBack({"routeMode":"car"/"bus"/"walk"/"cycle"})
 */
function nativeGetRouteMode(callBack) {
    mqq.invoke('poi', 'getRouteMode', function (data) {
        if (data.routeMode) {
            callBack(data.routeMode);
        } else {
            callBack(undefined);
        }
    })
}
/**
 * 获取收藏状态
 *  @param poi 完整信息
 * @param callback: {"isFavorite":0}
 */
function nativeIsFavorite(callBack) {

    mqq.invoke('poi', 'isFavorite', {'poi': poiData},function(data){
        //alert(JSON.stringify(data))
        if(data.isFavorite=="1") {
            // callBack(data.isFavorite);
            callBack("1");
        } else {
            callBack(undefined);
        }
    })

}
/**
 * 取消收藏
 *  @param poi 完整信息
 */
function nativeRemoveFavorite(callBack) {
    console.log(poiData)
    mqq.invoke('poi', 'removeFavorite', {'poi': poiData},function(data){
        if(data.success=="1") {
            // nativeShowTips("取消收藏");
            callBack("1");
        } else {
           // nativeShowTips("取消收藏失败！")
            callBack(undefined);
        }
    })
}
/**
 * 添加收藏
 *  @param poi 完整信息
 */
function nativeAddFavorite(callBack) {
    mqq.invoke('poi', 'addFavorite', {'poi': poiData},function(data){
        //alert(JSON.stringify(data))
        if(data.success==1) {
            callBack("1");
            // nativeShowTips("收藏成功")
        } else {
            callBack(undefined);
            //nativeShowTips("收藏失败！")
        }
    })
}

/**
 * 分享
 * @param poi 完整信息
 */
function nativeShare() {
    mqq.invoke('poi', 'share', {'poi': poiData});
}

/**
 * 打开客户端的周边页面
 * @param platform  设备平台，即'android'或'ios'
 * @param poi 完整信息
 */
function nativeOpenAround(platform) {
    mqq.invoke('poi', 'gotoPage',{
        'uri': 'nearby',
        'param': {'poi': poiData}
    });
}
/**
 * 打开客户端的街景页面
 * @param platform  设备平台，即'android'或'ios'
 * @param poi 完整信息
 */
function nativeOpenVista(platform) {
    mqq.invoke('poi', 'gotoPage',{
        'uri': 'streetView',
        'param': {'poi': poiData}
    });
}
/**
 * 去这里
 * @param routeMode 出行方式
 * @param startLat 出发经度
 * @param startLon 出发纬度
 * @param startName 出发地名
 * @param endLat 终点经度
 * @param endLon 终点纬度
 * @param endName终点地名
 * @param endUid终点地名
 */
function nativeGotoHere(routeMode,startLat,startLon,startName,endLat,endLon,endName,uid,isFuzzySearch,startCity,endCity,startUid) {
    // alert(routeMode)
    mqq.invoke('poi', 'gotoPage', {
        'uri': 'gotoHere',
        'param': {'routeMode': routeMode, 'startLat': startLat, 'startLon': startLon, 'startName': startName, 'endLat': endLat, 'endLon': endLon,'endName': endName,'endUid':uid,'endIsFuzzySearch':isFuzzySearch,'startCity':startCity,'endCity':endCity,"startUid":startUid}
    });
}
/**
 * 打开客户端的评论页面
 * @param platform  设备平台，即'android'或'ios'
 * @param uid   poi id
 */
function nativeOpenComment(platform, uid) {
    // 参数poi用于安卓端
    mqq.invoke('poi', 'gotoPage', {
        'uri': 'comment',
        'param': {'uid': uid}
    })
}
/**
 * 打开在线的H5界面
 * @param url   在线地址
 */
function nativeOnlineWebView(url) {
    mqq.invoke('poi', 'gotoPage',{
        'uri': 'onlineWebView',
        'param': {url: url}
    })
}
/**
 * 打开本地的H5界面
 * @param url   本地地址
 */
function nativeLocalWebView(url) {
    mqq.invoke('poi', 'gotoPage',{
        'uri': 'localWebView',
        'param': {url: url,showTitle:true}
    })
}
/**
 * 调用客户端推荐菜列表
 * @param recommend_menu 推荐菜数据
 */
function nativeDishList(recommend_menu) {
    mqq.invoke('poi', 'gotoPage', {'uri': 'recommendDishList', 'param': {'recommend_menu':recommend_menu}})
}
/**
 * 调用客户端推荐菜大图
 * @param recommend_menu 推荐菜列表
 * @param selectIndex 序列号
 */
function nativeDishBigPic(recommend_menu,selectIndex) {
    mqq.invoke('poi', 'gotoPage', {'uri': 'dishBigPic', 'param': {'recommend_menu': recommend_menu,'selectIndex':selectIndex}});
}
/**
 * 调用客户端评论大图
 * @param picUrlList 评论列表
 * @param selectIndex 序列号
 */
function nativeCommentBigPic(picUrlList,selectIndex) {
    mqq.invoke('poi', 'gotoPage', {'uri': 'commentBigPic', 'param': {'picUrlList':picUrlList,'selectIndex':selectIndex}});
}
/**
 * 跳转到纠错
 *  @param poi 完整信息
 */
function nativeReportError() {
    console.log(poiData);
    mqq.invoke('poi', 'gotoPage', {
        'uri': 'reportError',
        'param': {"poi":poiData}
    });
}
/**
 * 打开客户端的附近页面
 */
function nativeNearby() {
    mqq.invoke('poi', 'gotoPage', {'uri': 'nearby', 'param': {'poi': poiData}});
}

/**
 * 打开客户端的室内导览页面
 *  @param poi 完整信息
 * @param in_ma
 * @param in_cl
 * @param in_fl
 */
function nativeOpenIndoor(in_ma, in_cl, in_fl) {
    mqq.invoke('poi', 'gotoIndoor', {in_ma: in_ma, in_cl: in_cl, in_fl: in_fl,poi:poiData});
}
/**
 * 打开公交或地铁路线页面
 * * @param uid poi id
 * @param name poi name
 */
function nativeLineDetail(uid,name) {
    mqq.invoke('poi', 'gotoPage', {
        'uri': 'lineDetail',
        'param': {uid: uid, name: name}
    });
}
/**
 *  打开当前城市的地铁图
 * * @param url
 */
function nativeOpenSubway(url) {
    mqq.invoke('poi', 'gotoPage', {
        'uri': 'subway',
        'param': {"url": url}
    })
}
/**
 * 打开客户端的poi小页卡页面
 *  @param poi 完整信息
 */
function nativeOpenPoiPage() {
    mqq.invoke('poi', 'gotoPage', {
        'uri': 'poiPage',
        'param': {'poi':poiData}
    });
}

/*
    是否是我的位置
*/

function isMyLocation(callback){
     mqq.invoke('poi','isMyLocation',{}, function (data) {
        //alert(JSON.stringify(data))
        if(data) {
            callback(data)
        }else{
            callback(undefined)
        }
    })
}
function dianxinToPage(searchWord, searchBusiness, centerPoi,fromSource){
    mqq.invoke('poi', 'searchPois', {
        'searchWord': searchWord,
        'searchBusiness': searchBusiness,
        "centerPoi":centerPoi,
        "fromSource":fromSource,
        "click":"recommend"
    });
}
//更多
function moreToPage() {
    mqq.invoke('poi', 'gotoPage',{
        'uri': 'allPOICategory',
        'param': {'centerPoi': poiData}
    });
}

// 获取经纬度：
function nativeGetPosition(callBack) {
    mqq.invoke('common', 'getPosition', {},
        function (data) {
            if (data && data.status == 0) {
                callBack(data.lat, data.lon);
            } else {
                callBack(undefined, undefined);
            }
        });
}

// 跳转在线、离线H5页面：
function gotoH5(url) {
    mqq.invoke('poi', 'gotoPage', {
        'uri': 'poiRank',
        'param': {'url':url}
});
}

// 跳转小页卡：
function nativeOpenPoiPage() {
    mqq.invoke('poi', 'gotoPage', {
        'uri': 'poiPage',
        'param': {'poi':poiData}
    });
}

/**
 * 上报埋点
 */
function dataReport(code,data) {
    mqq.invoke("common", "dataReport", {
        "code": code,
        "data":data
    });
}
